@@ -33,11 +33,16 @@ if __name__ == '__main__':
     
     print '\nLooking for intervention strategies with ASP...'
     
-    def feedback(strategies):
-        sys.stdout.write("\r%s minimal intervention strategies have been found." % len(strategies))
-        sys.stdout.flush()
+    if arguments.feedback:
+        def feedback(strategies):
+            sys.stdout.write("\r%s minimal intervention strategies have been found." % len(strategies))
+            sys.stdout.flush()
+        
+        strategies = controller.control(scenarios, arguments.max_size, feedback=feedback)
+    else:
+        strategies = controller.control(scenarios, arguments.max_size)
+        print "%s minimal intervention strategies have been found." % len(strategies)
         
-    strategies = controller.control(scenarios, arguments.max_size, feedback=feedback)
     print '\n'
     
     strategies.sort(key=len)
