@@ -19,7 +19,7 @@
 import argparse
 import math
 
-VERSION = '1.6'
+VERSION = '1.7'
 
 def fit_tolerance(string):
     value = float(string)
@@ -92,6 +92,9 @@ def get_learn_args():
 
     parser.add_argument("--out", dest="outdir", default='.',
                         help="output directory path (Default to current directory)", metavar="O")
+                        
+    parser.add_argument("--no-feedback", dest="feedback", action='store_false',
+                        help="avoid printing online feedback.")
                                                 
     args = parser.parse_args()
     
@@ -118,6 +121,9 @@ def get_control_args():
         
     parser.add_argument("--out", dest="outdir", default='.',
                         help="output directory path (Default to current directory)", metavar="O")
+                        
+    parser.add_argument("--no-feedback", dest="feedback", action='store_false',
+                        help="avoid printing online feedback.")
 
     args = parser.parse_args()
     
