@@ -24,8 +24,15 @@ _ = lambda s: '"' + s + '"'
  
 root = __file__.rsplit('/', 1)[0]
 
+guess_prg           =  root + '/query/guess.lp'
 functions_prg       =  root + '/query/functions.lp'
-hyper_prg           =  root + '/query/hyper.lp'
 optimization_prg    =  root + '/query/optimization.lp'
+enumeration_prg     =  root + '/query/enum.lp'
+residual_prg        =  root + '/query/residual.lp'
+gtt_base_prg        =  root + '/query/gtt_base.lp'
+gtt_core_prg        =  root + '/query/gtt_core.lp'
+gtt_diff_prg        =  root + '/query/gtt_diff.lp'
 gtt_prg             =  root + '/query/gtt.lp'
 mutual_prg          =  root + '/query/mutual.lp'
+genbench_prg        =  root + '/query/genbench.lp'
+control_prg         =  root + '/query/control.lp'
\ No newline at end of file
